@@ -3,7 +3,9 @@
   database.cc
 
   database handling subroutines for xlogmaster.cc
+
   Copyright (C) 1998,1999 Georg C. F. Greve
+  Portions Copyright (C) 2005 Free Software Foundation, Inc.
   This is a GNU program
   
   This program is free software; you can redistribute it and/or modify
@@ -18,15 +20,16 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA
   
   
   Contact: 
            mailto:xlogmaster-bugs@gnu.org
            http://www.gnu.org/software/xlogmaster/
-  Secondary sources:
-           http://porter.desy.de/~greve/xlogmaster/
-           http://www.fusebox.hanse.de/xlogmaster/
+  
+  Last modification: Portion of groupify function re-written to fix
+                     segmentation faults.
+                     September 2005 - John S. Gaythorpe - Maintainer
 	 
 */
 
@@ -34,13 +37,14 @@
 
 #include "../config.h"
 #include "sysinc.H"
-#include "../import/import.h"
 #include "logclass.H"
 #include "database.H"
 #include "extern.H"
 
 /*}}}*/
 
+using namespace std;	/* jsg - added to fix cerr decl using gcc */
+
 /*{{{  Database Menu  */
 void
 startup_database_menu()
@@ -775,6 +779,7 @@ get_database(const gchar* directory)
 	      /*
 		Now we got the file in memory... let's interpret it
 	      */
+
 	      groupify(buffer, length, directory);
 	      
 	    }
@@ -827,12 +832,26 @@ groupify(gchar* buffer, gint length, const gchar* base_dir)
   gint x = 0;
   gchar* line = buffer;
   Log** array = NULL;
-  gchar* group_list_entry[3];
+  gchar* group_list_entry[2];
+  gchar fillstring[80];
   group_list_entry[0] 
     = group_list_entry[1] 
-    = group_list_entry[2] 
     = NULL;
-  
+  string bufferstuff = buffer;
+  string namef = "NAME";
+  string descf = "DESC";
+  string ldelf = "{";
+  string rdelf = "}";
+  string blankit (80,0);
+  string getdata = blankit;
+ std::string::size_type posit;
+ std::string::size_type lposit;
+ std::string::size_type rposit;
+ std::string::size_type y = 0;
+  delete group_list_entry[0];
+  group_list_entry[0] = new gchar[20];
+  delete group_list_entry[1];
+  group_list_entry[1] = new gchar[80];
   while ( x < length )
     {
       
@@ -842,53 +861,44 @@ groupify(gchar* buffer, gint length, const gchar* base_dir)
       
       buffer[x] = 0;
       
-      if ( regexec( gname_regex,
-		    line,
-		    0,
-		    NULL,
-		    0 )
-	   == 0 )
+	if (string(bufferstuff,y).find(namef) != string::npos) 
 	{
-	  /* This is a "NAME" line */
-	  
+	  /* This is a "NAME" line */	  
 	  if ( group_list_entry[0] != NULL )
 	    {
 	      delete group_list_entry[0];
-	      group_list_entry[0] = NULL;
+	      group_list_entry[0] = new gchar[20];
 	    }
-
-	  guint index = searchfor('{', line, 0);
-	  group_list_entry[0] = getstring('}', line, index+1);
-	  group_list_entry[0] = clean_string( group_list_entry[0] );
-	  
+	  blankit.copy(group_list_entry[0],20,0);
+	  lposit = string(bufferstuff,y).find(ldelf);
+	  rposit = string(bufferstuff,y).find(rdelf);
+	  getdata = bufferstuff.substr(lposit+1,rposit-lposit-1);
+	  y = rposit+2;
+	  getdata.copy(group_list_entry[0],rposit-lposit-1,0);
+	  getdata = blankit;
 	}
-      else if ( regexec( gdesc_regex,
-			 line,
-			 0,
-			 NULL,
-			 0 )
-		== 0 )
+	else if (string(bufferstuff,y).find(descf) != string::npos)
 	{
 	  /* This is a "DESCRIPTION" line */
-
 	  if ( group_list_entry[1] != NULL )
 	    {
 	      delete group_list_entry[1];
-	      group_list_entry[1] = NULL;
+	      group_list_entry[1] = new gchar[80];
 	    }
-	  
-	  guint index = searchfor('{', line, 0);
-	  group_list_entry[1] = getstring('}', line, index+1);
-	  group_list_entry[1] = clean_string( group_list_entry[1] );
-	 	  
+	  blankit.copy(group_list_entry[1],80,0);
+	  lposit = string(bufferstuff,y).find(ldelf);
+          rposit = string(bufferstuff,y).find(rdelf);
+	  getdata = bufferstuff.substr(y+lposit+1,rposit-lposit-1);
+	  y = rposit+1;
+	  getdata.copy(group_list_entry[1],rposit-lposit-1,0); 
+	  getdata = blankit;
 	}
-      else
+        else
 	{
 	  /* It is a FILENAME line, read the file... */
 	  gchar* fname = new gchar[ strlen(line) + 2 ];
 	  strcpy( fname, line );
 	  fname = clean_string( fname );
-	  
 	  /* make it into an absolute one... */
 	  gchar* filename = new gchar [ strlen(base_dir)
 				      + strlen(fname)
@@ -947,7 +957,6 @@ groupify(gchar* buffer, gint length, const gchar* base_dir)
 	      ( buffer[x] == 0 ||
 		buffer[x] == '\r' ||
 		buffer[x] == '\n'  )) x++;
-      
       line = &buffer[x];
       
     }
@@ -956,7 +965,7 @@ groupify(gchar* buffer, gint length, const gchar* base_dir)
   if ( group_list_entry[0] == NULL )
     {
 
-      group_list_entry[0] = new gchar[128];
+      group_list_entry[0] = new gchar[20];
       strcpy( group_list_entry[0] , "[no name]" );
 
     }
@@ -964,7 +973,7 @@ groupify(gchar* buffer, gint length, const gchar* base_dir)
   if ( group_list_entry[1] == NULL )
     {
       
-      group_list_entry[1] = new gchar[128];
+      group_list_entry[1] = new gchar[80];
       strcpy( group_list_entry[1] , "*** no description ***" );
       
     }
@@ -992,5 +1001,6 @@ groupify(gchar* buffer, gint length, const gchar* base_dir)
   if ( group_list_entry[1] != NULL )
     delete group_list_entry[1];
 }
+
 /*}}}*/
 
