@@ -18,14 +18,13 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA
   
   
   Contact: 
            mailto:xlogmaster-bugs@gnu.org
            http://www.gnu.org/software/xlogmaster/
   Secondary sources:
-           http://porter.desy.de/~greve/xlogmaster/
            http://www.fusebox.hanse.de/xlogmaster/
 	 
 */
@@ -34,7 +33,6 @@
 
 #include "../config.h"
 #include "sysinc.H"
-#include "../import/import.h"
 #include "logclass.H"
 #include "xlogmaster.H"
 #include "extern.H"
@@ -52,6 +50,7 @@
    to the GTK+ toolkit
 
  */
+using namespace std;	/* jsg - added because of cout and cerr complaints and not using std::cout etc */
 int 
 main (int argc, char *argv[])
 {
